#' aedl: Almost-exact inference for the DerSimonian-Laird test statistic
#'
#' The package implements almost-exact inference for the
#' DerSimonian-Laird test statistic in the normal-normal random-effects
#' meta-analysis model.
#'
#' @keywords internal
"_PACKAGE"
