% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/i2c.R
\name{aedl_i2c}
\alias{aedl_i2c}
\title{Corrected heterogeneity measure}
\usage{
aedl_i2c(
  I2hat,
  vi,
  sig2t,
  I2_grid = seq(0, 0.99, by = 0.01),
  a = 0,
  b = 1,
  nsim = 10000
)
}
\description{
Internal helper for \code{method = "i2c"}. The intended implementation uses the
row of \code{pI2sim} corresponding to the observed \code{I2hat}.
}
\keyword{internal}
