% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/i2c.R
\name{aedl_pI2_given_I2}
\alias{aedl_pI2_given_I2}
\title{Simulate p(I2hat | I2)}
\usage{
aedl_pI2_given_I2(I2, vi, sig2t, I2_grid, nsim = 10000)
}
\description{
Simulate p(I2hat | I2)
}
\keyword{internal}
