% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/density_tdl.R
\name{aedl_conditional_moments}
\alias{aedl_conditional_moments}
\title{Conditional Monte Carlo quantities for the DL statistic}
\usage{
aedl_conditional_moments(zi, x, K, sig2i, tau2)
}
\description{
Conditional Monte Carlo quantities for the DL statistic
}
\keyword{internal}
