% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/aedl-package.R
\docType{package}
\name{aedl-package}
\alias{aedl-package}
\title{aedl: Almost-exact inference for the DerSimonian-Laird test statistic}
\description{
The package implements almost-exact inference for the
DerSimonian-Laird test statistic in the normal-normal random-effects
meta-analysis model.
}
\author{
\strong{Maintainer}: Keisuke Hanada \email{keisuke.hanada.87@gmail.com} (\href{https://orcid.org/0000-0002-1444-0280}{ORCID})

}
\keyword{internal}
