% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/density_tdl.R
\name{aedl_v2tdls}
\alias{aedl_v2tdls}
\title{Conditional variance of the DL test statistic}
\usage{
aedl_v2tdls(cov_list, x, sig2i, K)
}
\description{
Conditional variance of the DL test statistic
}
\keyword{internal}
