% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print.R
\name{print.aedl}
\alias{print.aedl}
\title{Print an aedl object}
\usage{
\method{print}{aedl}(x, digits = max(3, getOption("digits") - 3), ...)
}
\arguments{
\item{x}{An object of class \code{"aedl"}.}

\item{digits}{Number of significant digits to print.}

\item{...}{Unused.}
}
\value{
Invisibly returns \code{x}, the input object of class \code{"aedl"}.
}
\description{
Print an aedl object
}
