% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/density_tdl.R
\name{aedl_density_tdl}
\alias{aedl_density_tdl}
\title{Density approximation for the DL test statistic}
\usage{
aedl_density_tdl(
  t_grid,
  K,
  sig2i,
  tau2,
  theta = 0,
  nsim = 10000,
  nsim_chi = 1e+05,
  n_tau = 1000
)
}
\description{
Internal helper. This file will contain the almost-exact mixture density for
the DerSimonian-Laird test statistic.
}
\keyword{internal}
