% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/density_tau2dl.R
\name{aedl_density_tau2dl}
\alias{aedl_density_tau2dl}
\title{Density approximation for the untruncated DL tau-squared estimator}
\usage{
aedl_density_tau2dl(K, sig2i, tau2, nsim_chi = 1e+05, n_tau = 1000)
}
\description{
Internal helper. This file will contain the chi-square-mixture approximation
currently represented by \code{pdf_tau2dl_fast()} in the prototype code.
}
\keyword{internal}
